==> simplevis_2.4.0.tar.gz: simplevis/README.md <==
<img src="man/figures/logo.png" height="150" align = "right">

<!-- badges: start -->
  [![CRAN status](https://www.r-pkg.org/badges/version/simplevis)](https://CRAN.R-project.org/package=simplevis)
  <!-- badges: end -->

# simplevis

### Introduction

`simplevis` is a package of `ggplot2` and `leaflet` wrapper functions designed to support effortless high quality `ggplot2` and `leaflet` visualisations for reports or interactive `shiny` apps.

The intent is that these can be made more consistently with less effort, code and expertise than would otherwise be required.

### Installation

Install stable version from CRAN:
`install.packages("simplevis")`

Install development version from github:
`devtools::install_github("statisticsNZ/simplevis")`

### Documentation

Webpage URL:

https://statisticsnz.github.io/simplevis/

R vignette:

`vignette("simplevis", "simplevis")`

---
__Copyright and Licensing__

The package is Crown copyright (c) 2020, Statistics New Zealand on behalf of the New Zealand Government, and is licensed under the MIT License.

<br /><a rel="license" href="https://creativecommons.org/licenses/by/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by/4.0/88x31.png" /></a><br />This document is Crown copyright (c) 2020, Statistics New Zealand on behalf of the New Zealand Government, and is licensed under the Creative Commons Attribution 4.0 International License. To view a copy of this license, visit https://creativecommons.org/licenses/by/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

==> simplevis_2.6.0.tar.gz: simplevis/README.md <==
<img src="man/figures/logo.png" height="150" align = "right">

<!-- badges: start -->
  [![CRAN status](https://www.r-pkg.org/badges/version/simplevis)](https://CRAN.R-project.org/package=simplevis)
  [![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/grand-total/simplevis?color=lightgrey)](https://r-pkg.org/pkg/simplevis)
  [![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/last-month/simplevis?color=lightgrey)](https://r-pkg.org/pkg/simplevis)
  [![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/last-week/simplevis?color=lightgrey)](https://r-pkg.org/pkg/simplevis)
  [![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/last-day/simplevis?color=lightgrey)](https://r-pkg.org/pkg/simplevis)
  <!-- badges: end -->

# simplevis

### Overview

`simplevis` is a package of wrapper functions to make 'ggplot2' and 'leaflet' visualisation easier and prettier.

### Installation

Install stable version from CRAN:
`install.packages("simplevis")`

Install development version from github:
`devtools::install_github("statisticsNZ/simplevis")`

### Documentation

Webpage URL:

https://statisticsnz.github.io/simplevis/

R vignette:

`vignette("simplevis", "simplevis")`

---
__Copyright and Licensing__

The package is Crown copyright (c) 2020, Statistics New Zealand on behalf of the New Zealand Government, and is licensed under the MIT License.

<br /><a rel="license" href="https://creativecommons.org/licenses/by/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by/4.0/88x31.png" /></a><br />This document is Crown copyright (c) 2020, Statistics New Zealand on behalf of the New Zealand Government, and is licensed under the Creative Commons Attribution 4.0 International License. To view a copy of this license, visit https://creativecommons.org/licenses/by/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
